@@ -204,9 +204,8 @@ function UW_apiLeakCheck(apiName) {
 function createSandbox(aScriptName, aContentWin, aChromeWin, aFirebugConsole, aUrl
 ) {
   var unsafeWin = aContentWin.wrappedJSObject;
-  var sandbox = new Components.utils.Sandbox(aContentWin);
+  var sandbox = new Components.utils.Sandbox(aContentWin, {sandboxPrototype: aContentWin});
 
-  sandbox.__proto__ = aContentWin;
   sandbox.unsafeWindow = unsafeWin;
   sandbox.XPathResult = Ci.nsIDOMXPathResult;
 
